==> jersey-server-2.4.1-sources.jar: org/glassfish/jersey/server/model/internal/ModelErrors.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.model.internal;

import java.util.List;

import org.glassfish.jersey.internal.Errors;
import org.glassfish.jersey.server.model.ResourceModelIssue;

import com.google.common.base.Function;
import com.google.common.collect.Lists;

/**
 * Utility to transform {@link Errors.ErrorMessage error messages} to {@link ResourceModelIssue}s.
 *
 * @author Michal Gajdos (michal.gajdos at oracle.com)
 */
public class ModelErrors {

    /**
     * Get all filed error messages as {@link ResourceModelIssue}s.
     *
     * @return non-null list of resource model issues.
     */
    public static List<ResourceModelIssue> getErrorsAsResourceModelIssues() {
        return getErrorsAsResourceModelIssues(false);
    }

    /**
     * Get error messages filed after {@link Errors#mark()} flag was set as {@link ResourceModelIssue}s.
     *
     * @return non-null list of resource model issues.
     */
    public static List<ResourceModelIssue> getErrorsAsResourceModelIssues(final boolean afterMark) {
        return Lists.transform(Errors.getErrorMessages(afterMark), new Function<Errors.ErrorMessage, ResourceModelIssue>() {
            @Override
            public ResourceModelIssue apply(final Errors.ErrorMessage input) {
                return new ResourceModelIssue(input.getSource(), input.getMessage(), input.getSeverity());
            }
        });
    }

}

==> jersey-server-2.10.2-sources.jar: org/glassfish/jersey/server/model/internal/ModelErrors.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.model.internal;

import java.util.List;

import org.glassfish.jersey.internal.Errors;
import org.glassfish.jersey.server.model.ResourceModelIssue;

import jersey.repackaged.com.google.common.base.Function;
import jersey.repackaged.com.google.common.collect.Lists;

/**
 * Utility to transform {@link Errors.ErrorMessage error messages} to {@link ResourceModelIssue}s.
 *
 * @author Michal Gajdos (michal.gajdos at oracle.com)
 */
public class ModelErrors {

    /**
     * Get all filed error messages as {@link ResourceModelIssue}s.
     *
     * @return non-null list of resource model issues.
     */
    public static List<ResourceModelIssue> getErrorsAsResourceModelIssues() {
        return getErrorsAsResourceModelIssues(false);
    }

    /**
     * Get error messages filed after {@link Errors#mark()} flag was set as {@link ResourceModelIssue}s.
     *
     * @return non-null list of resource model issues.
     */
    public static List<ResourceModelIssue> getErrorsAsResourceModelIssues(final boolean afterMark) {
        return Lists.transform(Errors.getErrorMessages(afterMark), new Function<Errors.ErrorMessage, ResourceModelIssue>() {
            @Override
            public ResourceModelIssue apply(final Errors.ErrorMessage input) {
                return new ResourceModelIssue(input.getSource(), input.getMessage(), input.getSeverity());
            }
        });
    }

}
